%
%--------------------------------------------------------------------------
% function [map] = FT_remove_elements_outside_map(map)
%
% A function for Matlab which finds the nan element closest to the centre 
% of the mirror map and removes all the points outside the radial position
% of this point.  Effectivley zooming in on the valid mirror map data.
%
% map:  mirror map in the standard structure
%
% Part of the Simtools package, http://www.gwoptics.org/simtools
% Charlotte Bond    03.05.2011
%--------------------------------------------------------------------------
%

% Description: Removes outer ring of NaN data from a mirror map
% Keywords: map, mirror, remove, data, nan

function [map] = FT_remove_elements_outside_map(map)

  % Find nan elements in map
  [ridx,cidx]=find(map.notnan==0);
  
  % Define x and y coordinates of nan points
  x=cidx-map.x0;
  y=ridx-map.y0;
  
  % Define radial coordinates
  r=sqrt(x.^2+y.^2);
  
  % Find the minimum radius - i.e. closest nan point
  radius=min(min(r));
  
  % Define x, y and radial coordinates for all the map data
  mygrid = FT_create_grid_for_map(map);
  
  % Find all points outside the minimum radius
  R2 = mygrid.X.^2/map.xstep^2+mygrid.Y.^2/map.ystep^2;
  outside=find(R2>=radius^2);
  
  % Set these elements to nan 
  map.data(outside)=nan;
  D=2*radius;
  
  % Remove unnecessary points (nan points) outside the valid map grid.
  Rx = round((ceil(D+6)/2));
  Ry = round((ceil(D+6)/2));
  if 2*Ry<mygrid.ypoints && 2*Rx<mygrid.xpoints
    x0 = round(map.x0);
    y0 = round(map.y0);
  
    new_data = map.data(y0-Ry:y0+Ry,x0-Rx:x0+Rx);
    map.data = new_data;
  end
  
  % Reassign nan values in map
  map.nan=isnan(map.data);
  map.notnan=not(map.nan);
  map = FT_recenter_mirror_map(map);

end

