%--------------------------------------------------------------------------
% [a_FP] = FT_FP_sidebands(fsig,a0,lambda,L,R1,T1,R2,sb_sign)
%
% A function for Matlab which calculates the amplitude and phase of the
% sidebands created and reflected from a Fabry-Perot cavity where the 
% cavity space is modulated by a gravitational wave (with h=1).  The 
% calculation is carried out for a linear cavity on resonance.
%
% fsig:     Gravitational wave frequency [Hz]
% a0:       Complex number representing the amplitude and phase of the beam
%           injected into the cavity [sqrt(W)].  
% lambda:   Laser wavelength [m]
% L:        Cavity length [m]
% R1:       ITM reflection coefficient (power)
% T1:       ITM transmission coefficient (power) 
%           R1 and T1 should satisfy R1+T1<=1
% R2:       ETM reflection coefficient (power).  R2 must satisfy R2<=1.
% sb_sign:  Sign of the sideband to calculate the amplitude and phase of.
%           1:  upper sideband
%           -1: lower sideband
%           The amplitudes of the upper and lower sidebands are the same,
%           the phases depend on the sign.
%
% a_FP:     Returned complex coefficient describing the amplitude and phase
%           of the reflected sideband [sqrt(W)].
%
% Charlotte Bond    28.01.2013
%--------------------------------------------------------------------------
%

function [a_FP] = FT_FP_sidebands(fsig,a0,lambda,L,R1,T1,R2,sb_sign)

    % Light/cavity parameters
    c=299792458;
    ksig = 2*pi*fsig/c;
    n = 1;
    
    % Make the cavity space resonanat
    L = round(L/lambda)*lambda;    
    
    % Reflection amplitude coefficients
    r1 = sqrt(R1);
    r2 = sqrt(R2);
    
    % Gravitational wave amplitude = 1
    h0 = 1;
    
    % Amplitude of sidebands created when a beam travels through a space
    % modulated by a GW
    asb = FT_GW_sidebands(lambda,h0,fsig,L,n,sb_sign);
    
    % Sideband amplitude from round-trip of the space
    a_arm = r2*asb.*(1+exp(-1i*sb_sign*ksig*L)); 
    
    % Amplitude of sidebands reflected from the cavity
    a_FP = a0 * (-T1/(1-r1*r2)) * (a_arm./(1-r1*r2*exp(-1i*2*sb_sign*ksig*L)));
    
    % If T1=1 (i.e. not ITM) the equation above adds an extra 180 deg 
    % phase, which needs to be corrected via an extra - 
    if T1==1
        a_FP = -a_FP;
    end
    
end

