%--------------------------------------------------------------------------
% function [Abs] = FT_GW_sidebands(lambda,h0,fsig,L,n,sb_sign)
%
% A function for Matlab which calculates the amplitude of the sidebands
% created when a light beam travels along a path modulated by a
% gravitational wave.
%
% lambda:   Wavelength of carrier light [m]
% h0:       Gravitational wave amplitude
% fsig:     Frequency of the gravitational wave [Hz]
% L:        Length of the path [m]
% n:        Index refection of the medium through which the beam travels
% sb_sign:  Sign of the sideband
%           1:  upper sideband
%           -1: lower sideband
%
% Asb:      Amplitude of the sidebands [sqrt(W)]
%
% Part of the Simtools package, http://www.gwoptics.org/simtools
% Charlotte Bond    07.11.2012
%--------------------------------------------------------------------------
%

function [Asb] = FT_GW_sidebands(lambda,h0,fsig,L,n,sb_sign)
    
    baseid = 'GW_sidebands';
    
    % Error meesgaes
    if sb_sign~=1 && sb_sign~=-1
        result='Invalid sideband sign: must be -1 (lower) or +1 (upper)';
        msgid=[baseid,':checkarguments']
        error(msgid,result);
    end

    % Carrier light parameters
    c = 299792458;
    f0 = c/lambda;
    w0 = 2*pi*f0;

    % Signal anglar frequency
    wsig = 2*pi*fsig;
 
    % Sideband amplitude
    Asb = (w0*h0./(2*wsig)) .* sin(wsig*L*n/(2*c));
    
    % Phase
    phi_sb = pi/2 - w0*L*n/c - sb_sign * wsig*L*n/(2*c);
    
    % Final sideband amplitude and phase
    Asb = Asb.*exp(1i*phi_sb);

end

