%--------------------------------------------------------------------------
% function [a_MICH] =
% FT_MICH_sidebands(fsig,a0,lambda,L,Rbs,Tbs,R1,T1,R2,sb_sign)
%
% A function for Matlab which calculates the sidebands created at the 
% output (dark) port of a Michleson interferometer when a gravitational 
% wave modulates the length of the arms.  The Michelson is on the dark 
% fringe with lx 0.25*lambda longer than ly and the arm cavities are on 
% resonance.  The gravitational wave is in the optimal polarisation, 
% modulating the y arm 180 degrees out of phase with the x arm. 
%
% fsig:     Frequency of the gravitational wave [Hz]
% a0:       Complex number describing the amplitude and phase of the
%           input light beam [sqrt(W)].
% lambda:   Laser wavelength [m]
% L:        Length of arm cavities [m]
% Rbs:      Beam-splitter reflection coefficient (power)
% Tbs:      Beam-splitter reflection coefficient (power)
% R1:       ITM reflection coefficient (power)
% T1:       ITM transmission coefficient (power)
%           For the case of no arm cavities (just a single end mirror) use
%           T1 = 1, R1 = 0.
% R2:       ETM reflection coefficient (power)
% sb_sign:  Sign of the sideband amplitude to calculate.
%           1:  Upper sideband
%           -1: Lower sideband
%
% a_MICH:   Returned complex sideband amplitude, including the amplitude 
%           and phase, at the dark port of the Michleson interferometer
%           [sqrt(W)].
%
% Charlotte Bond    26.02.2013
%--------------------------------------------------------------------------
%

function [a_MICH] = FT_MICH_sidebands(fsig,a0,lambda,L,Rbs,Tbs,R1,T1,R2,sb_sign)

    % Carrier and sideband parameters
    c=299792458;
    k0 = 2*pi/lambda;
    ksig = 2*pi*fsig/c;
    
    % BS parameters
    rbs = sqrt(Rbs);
    tbs = sqrt(Tbs);
    
    % Calculate the amplitude of the sidebands reflected from the arms
    a_FP = FT_FP_sidebands(fsig,a0,lambda,L,R1,T1,R2,sb_sign);
    
    % Put the Michelson on the dark fringe
    lx = 0.25*lambda;
    ly = 0;
    
    % Calculate the amplitude of the sidebands sent to the dark port
    a_MICH = 1i * tbs * rbs * a0 * a_FP .* (exp(-1i*(2*k0+sb_sign*ksig)*lx)-exp(-1i*(2*k0+sb_sign*ksig)*ly));
    
    
end

