%--------------------------------------------------------------------------
% function [a_SAG] =
% FT_SAG_sidebands(fsig,a0,lambda,L,Rbs,Tbs,R1,T1,R2,sb_sign)
% 
% A function for Matlab which calculates the amplitude of sidebands created
% in a Sagnac interferometer at the output (dark) port when a gravitational
% wave modulates the length of the arms.  The arm cavities are on resonance
% and the gravitational wave is in the optimal polarisation, modulating the
% y arm 180 degrees out of phase to the x arm.
%
% fsig:     Frequency of the gravitational wave [Hz]
% a0:       Complex number describing the amplitude and phase of the input
%           light beam [sqrt(W)].
% lambda:   Laser wavelength [m]
% L:        Length of the arms/ cavities [m]
% Rbs:      Beam-splitter reflection coefficient (power)
% Tbs:      Beam-splitter transmission coefficient (power)
% R1:       ITM reflection coefficient (power)
% T1:       ITM transmission coefficient (power)
%           For no arm cavities (just a single end mirror in the arms) use
%           R1 = 0, T1 = 1. 
% R2:       ETM reflection coefficient (power)
% sb_sign:  Sign of the sidebands to calculate.
%           1:  upper sideband
%           -1: lower sideband
%
% a_SAG:    Complex number describing the amplitude and phase of the
%           sideband at the output of the Sagnac interferometer [sqrt(W)].
%
% Charlotte Bond    26.02.2013
%--------------------------------------------------------------------------
%

function [a_SAG] = FT_SAG_sidebands(fsig,a0,lambda,L,Rbs,Tbs,R1,T1,R2,sb_sign)

    % Light parameters
    c=299792458;
    k0 = 2*pi/lambda;
    ksig = 2*pi*fsig/c;
    
    % Put the arm cavities on resonance
    L = round(L/lambda)*lambda;
    
    % Calculate the amplitude of the sidebands reflected from the arms
    a_FP = FT_FP_sidebands(fsig,a0,lambda,L,R1,T1,R2,sb_sign);

    % Reflection coefficients for the FP cavities for the carrier and
    % sideband frequency.
    rcav_k0 = FT_FP_refl(k0,L,R1,T1,R2);
    rcav_ksig = FT_FP_refl(k0+sb_sign*ksig,L,R1,T1,R2);
    
    % Final amplitude of the sidebands at the output port of the Sagnac
    % interferometer
    a_SAG = a0 * a_FP .* (rcav_k0 - rcav_ksig) * (Rbs+Tbs);

end

