%--------------------------------------------------------------------------
% function [tunings] = 
% FT_DR_FP_MICH_initial_tuning(infile,outfile,commands,mirrors,nodes,debug)
%
% A function for Matlab which takes an input FINESSE kat file describing
% the setup of a dual-recycled, fabry-perot michelson interferometer 
% (DR-FP-MICH) and performs several simulations to tune the different
% mirrors to their initial operating points.  This file tunes the following
% mirrors:
%
% Mirror                           * Operating point
%**************************************************************************
% ETMX (end test mass, x-arm)      * Circulating (or transmitted) carrier 
%                                  * light in x-arm is at a maximum
%**************************************************************************
% ETMY (end test maxx, y-arm)      * Circulating (or transmitted) carrier 
%                                  * light in y-arm is at a maximum
%**************************************************************************
% BS (central beam-splitter)       * Carrier light at interferometer output
%                                  * (AS port) is at a minimum
%**************************************************************************
% PRM (power-recyling mirror)      * Carrier light in the power-recycling
%                                  * cavity is at a maximum
%**************************************************************************
% SRM (signal-recycling mirror)    * 
%**************************************************************************
%
% To avoid hitting a sideband resonance the mirrors are tuned by looking at
% the amplitude of the carrier in the interferometer (using an 'ad' 
% detector).  The amplitude of tha carrier is detected as the mirrors are
% tuned, starting off by making the arm cavities resonant, then tuning the
% beam-splitter and finaly the recycling mirrors.  For each mirror the
% amplitude is detected over a range of tunings, gradually zooming in on
% the operating point until the difference from the previous operating
% point falls below a certain value.  The whole tuning process is carried
% out twice, firstly to quickly get the approximate operating points using
% maxtem 0 and secondly using the approximate operating points to then tune
% to the right opearting points using the value of maxtem set in the kat
% file. Finally the original kat file is written to a new file, including
% the tunings of the individual mirrors.
%
% infile:       The input FINEESE file (kat file) describing the DR-FP-MICH
%               interferometer to be tuned.  Each command line in this file
%               should be contained within a FINESSE block.
% outfile:      The output FINESSE file to be written including the
%               original structure and command lines.
% commands:     Vector of strings, e.g. {'detectors' 'xaxis'} which contain
%               the names of the blocks which contain detector or axis 
%               commands in the input file.  These blocks are ignored in 
%               the simulations to find the operating points, so should 
%               not include any commands relevant to the structure or 
%               values of the interferometer (i.e. no mirror commands,
%               'const' etc.).
% mirrors:      A vector of strings containing the names (matching those in 
%               the input file) of the 5 mirrors to tune.  These names must
%               be entered in the correct order:
%               {'ETMX' 'ETMY' 'BS' 'PRM' 'SRM'}
%               If there is not a power/signal recycling mirror use 'off' 
%               in place of the PRM/SRM name.
% nodes:        A vector or strings containing the names of the nodes
%               (matching their names in the input file) for the relevant
%               ports for the detection of each operating point.  The names
%               must be in the right order, matching the order of mirrors.
%               ===========================================================
%               nodes{1}:   port for ETMX, should be inside or at the
%                           transmission port of the x-arm cavity.
%               nodes{2}:   port for ETMY, should be inside or at the
%                           transmission port of the y-arm cavity.
%               nodes{3}:   port for BS, should be the output of the
%                           interferometer, the anti-symmetric (AS) port.
%               nodes{4}:   port for PRM, should be inside or at the
%                           transmission port of the power-recycling
%                           cavity.
%               nodes{5}:   port for the SRM.
%               ===========================================================
% debug:        1x5 vector indicating whether the output of each search for
%               an operating point should be displayed, i.e. the plots of
%               the scans over the operating points.  The five different
%               values are for the five different mirrors (in the same
%               order as the mirrors) where 1 plots the output and 0
%               suppresses it.
%
% tunings:      Returned 1x5 vector of mirror tunings representing the
%               different operating points [deg].
% 
% Charlotte Bond    13.02.2013
%--------------------------------------------------------------------------
%

function [tunings] = FT_DR_FP_MICH_initial_tuning(infile,outfile,commands,mirrors,nodes,debug)
    
    % Parameters for the scans
    % Tuning threshold and the allowed error between successive scans
    tuning_threshold = 1e-10;
    relative_err = 1e-2;
    % Number of zooms
    zooms = 3;
    % Number of points and ranges for the scans
    npoints = 300;
    range = 90;
    
    % Initilise Finesse
    FT = FT_init_Finesse();
    
    % Create a new 'run' variable, a structure to hold FINESSE related data
    Run1 = FT_create_new_kat_run();
    
    % Set temporary filename
    tmpfile='tmpfile_tuning.kat';
    Run1.filename=tmpfile;
    
    % Read in blocks from infile
    blocks=FT_read_blocks_from_file(infile);

    % Find each command block and remove it from the current blocks
    for i=1:length(commands)
        command_blocks(i)=blocks(FT_index_of_block(blocks,commands{i}));
        % Remove blocks that we do not need
        blocks(FT_index_of_block(blocks,commands{i}))=[];
    end
    
    % Store each mirror and node name
    etmx = mirrors{1};
    etmy = mirrors{2};
    bs = mirrors{3};
    prm = mirrors{4};
    srm = mirrors{5};
    
    nptx = nodes{1};
    npty = nodes{2};
    nas = nodes{3};
    npop = nodes{4};
    npos = nodes{5};
    
    % Read in the mirror parameters from blocks
    if ~strcmp(etmx,'off')
        [R_ETMX,T_ETMX,L_ETMX,phi_ETMX] = FT_read_mirror_parameters_from_blocks(blocks,etmx);
    end
    if ~strcmp(etmy,'off')
        [R_ETMY,T_ETMY,L_ETMY,phi_ETMY] = FT_read_mirror_parameters_from_blocks(blocks,etmy);
    end
    
    [R_BS,T_BS,L_BS,phi_BS] = FT_read_mirror_parameters_from_blocks(blocks,bs);
    
    % Read in original reflective coefficients for recycling mirrors
    if ~strcmp(prm,'off')
        [R_PRM,T_PRM,L_PRM,phi_PRM] = FT_read_mirror_parameters_from_blocks(blocks,prm);
    end
    if ~strcmp(srm,'off')
        [R_SRM,T_SRM,L_SRM,phi_SRM] = FT_read_mirror_parameters_from_blocks(blocks,srm);
    end
    
    % Read in intial maxtem
    maxtem = FT_read_maxtem_from_blocks(blocks);
    if isnan(maxtem)==0
        % Start off with maxtem at minimum (i.e. max order of tem modes)
        [gc,max_order] = FT_read_TEM_from_blocks(blocks);
        blocks = FT_replace_maxtem_in_blocks(blocks,max_order);
    end
    
	% Setting R_PRM=0 
	if ~strcmp(prm,'off')
        [bi,li,mtype_prm] = FT_find_mirror_in_blocks(blocks,prm);
        if mtype_prm==0 || mtype_prm==2
            blocks = FT_replace_mirror_parameter_in_blocks(blocks,prm,'R',0);
        end
        if mtype_prm<2
            blocks = FT_replace_mirror_parameter_in_blocks(blocks,prm,'T',1);
        end
        if mtype_prm>0
            blocks = FT_replace_mirror_parameter_in_blocks(blocks,prm,'L',0);
        end
	end
    
	% Setting R_SRM=0
	if ~strcmp(srm,'off')
        [bi,li,mtype_srm] = FT_find_mirror_in_blocks(blocks,srm);
        if mtype_srm==0 || mtype_srm==2
            blocks = FT_replace_mirror_parameter_in_blocks(blocks,srm,'R',0);
        end
        if mtype_srm<2
            blocks = FT_replace_mirror_parameter_in_blocks(blocks,srm,'T',1);
        end
        if mtype_srm>0
            blocks = FT_replace_mirror_parameter_in_blocks(blocks,srm,'L',0);
        end
    end
    
	ntimes = 2;
    if ~strcmp(prm,'off')
        ntimes = 3;
    elseif ~strcmp(srm,'off')
        ntimes = 3;
    end
    
    % Perform tunigns twice, once with maxtem 0 and once with the value for
    % maxtem set in infile    
    for i=1:ntimes
        
        Nm = 0;
        
        %======================================================================
        %============ 1. Tuning arm cavities to be on resonance ===============
        %======================================================================
        %----------------------------------------------------------------------
        % Tuning the x arm cavity
        if ~strcmp(etmx,'off')
            tuning = phi_ETMX;
            tuning = scan_for_operating_point(FT,Run1,blocks,etmx,nptx,tuning,range,npoints,'max',relative_err,zooms,debug(1));
            
            if abs(tuning) < tuning_threshold
                tuning=0.0;
            end
            
            % Setting tuning for x arm
            phi_ETMX = tuning;
            Nm = Nm+1;
            tunings(Nm) = phi_ETMX;
            blocks = FT_replace_mirror_parameter_in_blocks(blocks,etmx,'phi',phi_ETMX);
            fprintf('Setting %s tuning to %f\n',etmx,phi_ETMX);
        end
        if ~strcmp(etmy,'off')
            %----------------------------------------------------------------------
            % Tuning the y arm cavity
            tuning = phi_ETMY;
            tuning = scan_for_operating_point(FT,Run1,blocks,etmy,npty,tuning,range,npoints,'max',relative_err,zooms,debug(2));
            
            if abs(tuning) < tuning_threshold
                tuning=0.0;
            end
            
            % Setting tuning for y arm
            phi_ETMY = tuning;
            Nm = Nm+1;
            tunings(Nm) = phi_ETMY;
            blocks = FT_replace_mirror_parameter_in_blocks(blocks,etmy,'phi',phi_ETMY);
            fprintf('Setting %s tuning to %f\n',etmy,phi_ETMY);
        end
        %----------------------------------------------------------------------
        %======================================================================
        %======================================================================
         
		% HOMs can greatly effect dark fringe
        if isnan(maxtem)==0
            blocks = FT_replace_maxtem_in_blocks(blocks,maxtem);
        end
        
		%======================================================================
        %============ 2. Tuning BS to minimise power at AS port ===============
        %======================================================================
        % Tuning the BS
        tuning = phi_BS;
        tuning = scan_for_operating_point(FT,Run1,blocks,bs,nas,tuning,range,npoints,'min',relative_err,zooms,debug(3));
        
        if abs(tuning) < tuning_threshold
            tuning=0.0;
        end
        
        % Setting BS tuning
        phi_BS = tuning;
        Nm = Nm+1;
        tunings(Nm) = phi_BS;
        blocks = FT_replace_mirror_parameter_in_blocks(blocks,bs,'phi',phi_BS);
        fprintf('Setting %s tuning to %f\n',bs,phi_BS);
        %======================================================================
        %======================================================================
        
        if ~strcmp(prm,'off')
            %==============================================================
            %======= 3. Tuning PRM to maximise power at POP port ==========
            %==============================================================
            % Set PRM reflectivity back to normal
            if mtype_prm==0 || mtype_prm==2
                blocks = FT_replace_mirror_parameter_in_blocks(blocks,prm,'R',R_PRM);
            end
            if mtype_prm<2
                blocks = FT_replace_mirror_parameter_in_blocks(blocks,prm,'T',T_PRM);
            end
            if mtype_prm>0
                blocks = FT_replace_mirror_parameter_in_blocks(blocks,prm,'L',L_PRM);
            end
            % Tuning the power-recyling cavity
            tuning = phi_PRM;
            tuning = scan_for_operating_point(FT,Run1,blocks,prm,npop,tuning,range,npoints,'max',relative_err,zooms,debug(4));
    
            if abs(tuning) < tuning_threshold
                tuning=0.0;
            end
    
            % Setting BS tuning
            phi_PRM = tuning;
            Nm = Nm+1;
            tunings(Nm) = phi_PRM;
            blocks = FT_replace_mirror_parameter_in_blocks(blocks,prm,'phi',phi_PRM);
            fprintf('Setting %s tuning to %f\n',prm,phi_PRM);
            %==============================================================
            %==============================================================
        end
        
        if ~strcmp(srm,'off')
            if i==2
                %==============================================================
                %========= 4. Tuning SRM for broadband SRM tuning =============
                %==============================================================
                % Set SRM reflectivity back to normal
                if mtype_srm==0 || mtype_srm==2
                    blocks = FT_replace_mirror_parameter_in_blocks(blocks,srm,'R',R_SRM);
                end
                if mtype_srm<2
                    blocks = FT_replace_mirror_parameter_in_blocks(blocks,srm,'T',T_SRM);
                end
                if mtype_srm>0
                    blocks = FT_replace_mirror_parameter_in_blocks(blocks,srm,'L',L_SRM);
                end
                % Tuning the signal recycling cavity
                tuning = phi_SRM;
                tuning = scan_for_operating_point(FT,Run1,blocks,srm,npos,tuning,range,npoints,'min',relative_err,zooms,debug(4));
    
                if abs(tuning) < tuning_threshold
                    tuning=0.0;
                end
    
                % Setting BS tuning
                phi_SRM = tuning+srm_tuning;
                Nm = Nm+1;
                tunings(Nm) = phi_SRM;
                blocks = FT_replace_mirror_parameter_in_blocks(blocks,srm,'phi',phi_SRM);
                fprintf('setting %s tuning to %f\n',srm,phi_SRM);
                %==============================================================
                %==============================================================
            end
        end
        
    end
    
    if length(commands)>0
        % Writing new output file, adding command lines back in
        FT_write_blocks_into_file([blocks,command_blocks],outfile);
    else
        FT_write_blocks_into_file(blocks,outfile);
    end

end

%--------------------------------------------------------------------------
% function [tuning] = scan_for_operating_point(FT,Run,blocks,mirror,node,x0,
%                           range,npoints,op_point,rel_err,zooms,verbose)
% 
% A function which scans for the operating point at a given node by tuning
% a particular mirror over a certain range in a FINESSE interferometer 
% setup and looking at the carrier amplitude.
%
% FT:       FINESSE structure giving location and name of FINESSE
%           executable.
% Run:      Structure containing data about a particular FINESSE
%           simulation, the filename and output data.
% blocks:   Block structure containing the FINESSE commands.
% mirror:   Name of the mirror to be tuned.
% node:     Name of the node at which to detect the carrier amplitude.
% x0:       Initial tuning position [deg]
% range:    Tuning range (goes from x0-range to x0+range) [deg]
% npoinst:  Number of points to use in the scan.
% op_point: The operating point.
%           'max':  the operating point is at the maximum amplitude.
%           'nin':  the operating point is at the minimum amplitude.
% rel_err:  Allowed error in tuning.
% zooms:    Number of times to zoom into the operating point.
% verbose:  1: plot scan
%           0: no output
%
% Charlotte Bond 19.02.2013
%--------------------------------------------------------------------------
%

function [tuning] = scan_for_operating_point(FT,Run,blocks,mirror,node,x0,range,npoints,op_point,rel_err,zooms,verbose)
    
    % Strating values
    tuning = x0;
    f0 = 0;
    err = 10*rel_err;
    i = 0;

    % Scan over smaller and smaller range until the number of zooms is
    % completed and the difference from the previous tuning is smaller than
    % the allowed error
    while err>rel_err || i<=zooms
        i = i+1;
        
        % Detect carrier amplitude as mirror is tuned
        Run = FT_ad_scan(FT,Run,blocks,mirror,node,f0,0,tuning,range,npoints);
        
        % Find the operating point
        if strcmp(op_point,'max')
            new_tuning = Run.x(max(find(Run.y(:,1)==max(Run.y(:,1)))));
        elseif strcmp(op_point,'min')
            new_tuning = Run.x(max(find(Run.y(:,1)==min(Run.y(:,1)))));
        end
        
        % Relaive difference from previous operating point
        err = 2*abs(tuning-new_tuning)/abs(tuning+new_tuning);
        if isnan(err)
            err = 10*rel_err;
        end
        
        % Reset tuning and narrow range
        tuning = new_tuning;
        range = 4*range/npoints;
        
        % Plot scan if required
        if verbose==1
            figure
            semilogy(Run.x,Run.y(:,1))
            xlabel(sprintf('%s tuning [phi]',mirror))
            ylabel(sprintf('carrier amplitude (%s) [a.u.]',node))
            drawnow;
        end
    end
    
    % Clean the FINESSE run
    FT_kat_clean(Run);
    
end
