%--------------------------------------------------------------------------
% function [map_out,A,Rc] = FT_remove_zernike_curvatures_from_map(map,curvature)
%
% A Matlab function that preforms an inner product between a map surface 
% and particular Zernike polynomials, removing the resulting polynomials
% from the map surface.  The polynomials used here are the Zernike 
% polynomials defining mirror curvature, Z02, constant curvature, and
% Z-22 and Z+22, astigmatism.
%
% map:          The map surface from which the curvatures will be removed.
% curvature:    'all':          Astigmatism and constant curvature
%               'constant':     Just remove constant curvature (i.e. Z_0^2)
%               'astigmatism':  Just remove astigmatism
%
% map_out:      Returned map with curvatures removed
% A:            Amplitudes of removed polynomials [nm]
%               If removing 'all', A = [A2-2 A20 A2+2], if 'constant', 
%               A = A20, if 'astigmatism' A = [A2-2 A2+2]. 
% Rc:           Equivalent curvature removed.  Rc = [Rcx Rcy] (really 
%               maximum and minimum Rcs). N.B. if 'constant' or 
%               'astigmatism' remember that the missing curvature terms 
%               will contribute to the Rc).  
% 
% Part of the Simtools package, http://www.gwoptics.org/simtools
% Charlotte Bond    09.02.11
%--------------------------------------------------------------------------
%

function [map_out,A,Rc]=FT_remove_zernike_curvatures_from_map(map,curvature)
    
    % Error messages
    if (~strcmp(curvature,'astigmatism') && ~strcmp(curvature,'constant')...
             && ~strcmp(curvature,'all'))
        msg = 'Invalid value: curvature must be "constant", "astigmatism" or "all"'
        msgid = [baseid,':checkarguments']
        error(msgid,result);
    end

    % Zernike map convolution up to order 2 (don't save the data)
    zc = FT_zernike_map_convolution(map,2,0);
   
    % All curvatures have n = 2
    n=2;
  
    % Set values of m for different conditions
    if (strcmp(curvature,'constant'))
        mc=0;
    elseif (strcmp(curvature,'astigmatism'))
        mc=[-2 2];
    elseif (strcmp(curvature,'all'))
        mc=[-2 0 2];
    end
        
    map_out = map;
    
    % Remove curvature polynomials from the map
    for i=1:length(mc)

        m=mc(i);
      
        A(i) = FT_get_zernike_coefficient(zc,n,m); 
        
        % Remove polynomial
        map_out=FT_remove_zernike_polynomial_from_map(map_out,n,m,A(i));
    
    end
    
	% Put into nm										 
	A = A*map.scaling*1e9;										 
											 
    % Calculate equivalent radius of curvature
    R = map.xstep*FT_find_map_radius(map);
    if length(mc)==1
        Rc = FT_Znm_to_Rc(A,R);
    elseif length(mc)==2
        A22 = sqrt(A(1)^2+A(2)^2);
        Rc = FT_Znm_to_Rc([0 A22],R);
    else
        A22 = sqrt(A(1)^2+A(3)^2);
        Rc = FT_Znm_to_Rc([A(2) A22],R);
    end

    
end

