%--------------------------------------------------------------------------
% function [U_bulk,coeffs] = FT_thermal_distortion_from_bulk_absorption(beam,mirror,r,num_terms)
%
% A Matlab function which calculates an approximation of the thermal
% distortion of a mirror surface due to absorption of power in the bulk of
% the mirror (or substrate).  The approximation expands the distortion as a
% series of bessel functions, for a mirror in equilibrium.  The equations
% are taken from the Living Review, 'On Special Optical Modes and Thermal 
% Issues in Advanced GW Interferometric Detectors', Vinet, 2009.
%
% N.B. Currently only valid for an incident LG00 beam.
%
% beam:     Structure containing information about the incident beam (see
%           FT_init_thermal_beam.m).
% mirror:   Structure containing thermal properties of the mirror (see
%           FT_init_thermal_mirror.m).
% r:        Vector of radial coordinates [m]
% num_terms:Number of bessel terms to include in series.
%
% U_bulk:   Returned surface distortion [m]
% coeffs:   Coefficients for bessel series expansion. 
%
% Part of the Simtools package, http://www.gwoptics.org/simtools
% Charlotte Bond 13.11.2013
%--------------------------------------------------------------------------
%

function [U_bulk,coeffs] = FT_thermal_distortion_from_bulk_absorption(beam,mirror,r,num_terms)
    
    % Mirror and beam parameters 
    % Currently only valid for LG00
    p = 0;
    l = 0;  
    
    % Mirror parameters
    a = mirror.a;
    h = mirror.h;
    K = mirror.K;
    Babs = mirror.Babs;
    X = mirror.X;
    alpha = mirror.alpha;
    Y = mirror.Y;
    pois = mirror.pois;
    
    % Beam parameters
    Power = beam.P;
    lambda = beam.lambda;
    w = beam.w;
    
    % Lens is axis-symmetric
    r_abs = abs(r);
    
    % Constants
    C1 = alpha*(1+pois)*Babs*Power*a/(pi*K);    
    zeta_n = FT_bessel_zeros(l,X,num_terms);
    pn = FT_calculate_fourier_bessel_coefficients(p,l,X,w,a,num_terms);
    gamma_n = zeta_n*h/(2*a);
    Tn = sinh(gamma_n).*cosh(gamma_n)+gamma_n;
    d1n = zeta_n.*sinh(gamma_n)+X*cosh(gamma_n);
    
    U_bulk = 0;
    
    % Calculate coefficents for thermal distortion in terms of bessel
    % functins
    for n=1:num_terms
        
        C2 = pn(n)/zeta_n(n)^3 * sinh(gamma_n(n));
        t1 = 2*sinh(gamma_n(n))/Tn(n);
        t2 = X/d1n(n);
        
        J0 = besselj(0,zeta_n(n)*r_abs/a);
        
        coeffs(n) = -C1*C2*(t1-t2);
        
        U_bulk = U_bulk + coeffs(n)*(1-J0);
    
    end
        
end

