%--------------------------------------------------------------------------
% function [uz_coat,duz_coat] =
% FT_thermal_distortion_from_coating_absorption(beam,mirror,r,num_terms)
%
% A function for Matlab which calculates an approximation of the distortion
% of a mirror due to heating by an incident laser beam and absorption in 
% the mirror coating, in the steady state.
%
% N.B. Currently only valid for an incidnet LG00 beam.
%
% beam:     Structure storing the parameters of the beam (see
%           FT_init_thermal_beam.m).
% mirror:   Structure storing thermal properties for the mirror (see
%           FT_init_thermal_mirror.m).
% r:        Radial coordinate [m]
% num_terms:Number of terms to include in approximation.  (50 terms is
%           usually sufficient).
% 
% U_coat:   Returned distortion of the mirror surface [m]
% coeffs:   Coefficients in expansion of thermal distortion as sum of bessel
%           functions.
% SV:       Coefficients for Saint-Venant correction.
%
% Equations taken from Vinet 2009, Thermal issues in GW detectors and the
% Virgo Optics book.
% 
% Part of the Simtools package, http://www.gwoptics.org/simtools
% Charlotte Bond    11.02.2012
%--------------------------------------------------------------------------
%

function [U_coat,coeffs,SV] = FT_thermal_distortion_from_coating_absorption(beam,mirror,r,num_terms)

    % Mirror and beam parameters 
    % Currently only valid for LG00
    p = 0;
    l = 0;  
    
    % Mirror parameters
    a = mirror.a;
    h = mirror.h;
    K = mirror.K;
    Cabs = mirror.Cabs;
    X = mirror.X;
    alpha = mirror.alpha;
    Y = mirror.Y;
    pois = mirror.pois;
    
    % Beam parameters
    Power = beam.P;
    lambda = beam.lambda;
    w = beam.w;
    
    % Lens is axis-symmetric
    r_abs = abs(r);
    
    % Constants
    c1 = alpha*(1+pois)*Cabs*Power/(2*pi*K);
    c2 = -12*alpha*Y*X*Cabs*a*Power/(pi*K*h^3);
    
    % Calculate coefficients
    zeta_n = FT_bessel_zeros(2*l,X,num_terms);
    pn = FT_calculate_fourier_bessel_coefficients(p,l,X,w,a,num_terms);
    gamma_n = zeta_n*h/(2*a);
    d1n = zeta_n.*sinh(gamma_n)+X*cosh(gamma_n);
    d2n = zeta_n.*cosh(gamma_n)+X*sinh(gamma_n);
    
    % Approximation of surface distortion
    uz = 0;
    w1 = 0;
    
    % Calculate distortion as bessel sum
    for s=1:num_terms
        
        % Negative compared to Vinet 2009, for match Finesse convention
        coeffs(s) =  - c1 * pn(s)/zeta_n(s) * (sinh(gamma_n(s))/d1n(s) + cosh(gamma_n(s))/d2n(s)); 
        w1 = w1 - c2*pn(s)*besselj(0,zeta_n(s))/(zeta_n(s)^4)*(gamma_n(s)*cosh(gamma_n(s))-sinh(gamma_n(s)))/d2n(s);
        uz = uz + coeffs(s)*(1-besselj(2*l,zeta_n(s)*r_abs/a));
       
    end
    
    % Saint-Venant correction
    SV = -(1-pois)/(2*Y)*w1;
    duz = SV * r.^2;
    
    % Final thermal distortion 
    U_coat = uz + duz;

end

